Conversation
^^^^^^^^^^^^

Conversation exchange has such essentials components:

* "Message" send to SFChat server
* "Long pulling" get new messages and displays on a chat
* If message was successfully sent to addresser then it would be removed from database
 
